import CS rpm-ostree-2022.10.117.g52714b51-3.el8

This commit is contained in:
Andrew Lukoshko 2024-04-03 14:34:47 +00:00
parent 53bfb9694f
commit db9432d7e9
5 changed files with 109 additions and 9 deletions

2
.gitignore vendored
View File

@ -1 +1 @@
SOURCES/rpm-ostree-2022.10.115.g15eba7b1.tar.xz
SOURCES/rpm-ostree-2022.10.117.g52714b51.tar.xz

View File

@ -1 +1 @@
4ddb108fc95d35d6fce3925410459ec2452d7c5d SOURCES/rpm-ostree-2022.10.115.g15eba7b1.tar.xz
43d5b34cf6b8c77fc2f17429dcc1d385c885b032 SOURCES/rpm-ostree-2022.10.117.g52714b51.tar.xz

View File

@ -0,0 +1,48 @@
From f340dbbfd6a3acc8b85d487a32a78c4517ace1c4 Mon Sep 17 00:00:00 2001
From: Colin Walters <walters@verbum.org>
Date: Wed, 7 Dec 2022 20:14:06 -0500
Subject: [PATCH] override: Honor `--install` in container case too
Closes: https://github.com/coreos/rpm-ostree/issues/4192
---
ci/test-container.sh | 8 ++++++--
src/app/rpmostree-override-builtins.cxx | 1 +
2 files changed, 7 insertions(+), 2 deletions(-)
diff --git a/src/app/rpmostree-override-builtins.cxx b/src/app/rpmostree-override-builtins.cxx
index 41ab56f4..0c07ff53 100644
--- a/src/app/rpmostree-override-builtins.cxx
+++ b/src/app/rpmostree-override-builtins.cxx
@@ -204,6 +204,7 @@ handle_override (RPMOSTreeSysroot *sysroot_proxy, RpmOstreeCommandInvocation *in
CXX_TRY_VAR (pkgs, rpmostreecxx::stage_container_rpm_raw_fds (fds), error);
treefile->add_packages_override_replace_local (pkgs);
}
+ treefile->add_packages (util::rust_stringvec_from_strv (install_pkgs), true);
treefile->add_packages_override_remove (util::rust_stringvec_from_strv (override_remove));
return rpmostree_container_rebuild (*treefile, cancellable, error);
}
--
2.41.0

View File

@ -0,0 +1,38 @@
From cb777d950511e29dcb822b4ccba23e43cd63e9cb Mon Sep 17 00:00:00 2001
From: Joseph Marrero <jmarrero@redhat.com>
Date: Fri, 4 Aug 2023 08:27:39 -0400
Subject: [PATCH] scripts: also ignore kernel-debug-modules.posttrans
---
rust/src/scripts.rs | 13 +++++++++++++
1 file changed, 13 insertions(+)
diff --git a/rust/src/scripts.rs b/rust/src/scripts.rs
index 1f59e390..b8ab6623 100644
--- a/rust/src/scripts.rs
+++ b/rust/src/scripts.rs
@@ -21,8 +21,21 @@ static IGNORED_PKG_SCRIPTS: phf::Set<&'static str> = phf_set! {
// XXX: we should probably change this to instead ignore based on the kernel virtual Provides
"kernel.posttrans",
"kernel-core.posttrans",
+ "kernel-modules.posttrans",
+ "kernel-redhat-core.posttrans",
+ "kernel-redhat-modules.posttrans",
"kernel-debug-core.posttrans",
+ "kernel-debug-modules.posttrans",
+ "kernel-redhat-debug-core.posttrans",
+ "kernel-redhat-debug-modules.posttrans",
"kernel-automotive-core.posttrans",
+ "kernel-automotive-modules.posttrans",
+ "kernel-automotive-debug-core.posttrans",
+ "kernel-automotive-debug-modules.posttrans",
+ "kernel-rt-core.posttrans",
+ "kernel-rt-modules.posttrans",
+ "kernel-rt-debug-core.posttrans",
+ "kernel-rt-debug-modules.posttrans",
// Additionally ignore posttrans scripts for the Oracle Linux `kernel-uek` package
"kernel-uek.posttrans",
// Legacy workaround
diff --git a/ci/test-container.sh b/ci/test-container.sh
index be0f9549..342808e4 100755
--- a/ci/test-container.sh
+++ b/ci/test-container.sh
@@ -84,11 +84,15 @@ rpm-ostree override replace --experimental --from repo=fedora-coreos-pool \
rpm -q afterburn-5.2.0-4.fc36.x86_64 afterburn-dracut-5.2.0-4.fc36.x86_64
-# test repo override by pkgname
-rpm-ostree override replace --experimental \
+# test repo override by pkgname, and also test --install
+if rpm -q strace; then
+ echo "strace should not be installed"; exit 1
+fi
+rpm-ostree override replace --install strace --experimental \
--from repo=copr:copr.fedorainfracloud.org:group_CoreOS:continuous \
afterburn \
afterburn-dracut
+rpm -q strace
# the continuous build's version has the git rev, prefixed with g
rpm -q afterburn | grep g
--
2.41.0

View File

@ -3,14 +3,17 @@
Summary: Hybrid image/package system
Name: rpm-ostree
Version: 2022.10.115.g15eba7b1
Release: 2%{?dist}
Version: 2022.10.117.g52714b51
Release: 3%{?dist}
License: LGPLv2+
URL: https://github.com/coreos/rpm-ostree
# This tarball is generated via "cd packaging && make -f Makefile.dist-packaging dist-snapshot"
# in the upstream git. It also contains vendored Rust sources. This is generated from the "rhel8" branch.
Source0: https://github.com/coreos/rpm-ostree/releases/download/v%{version}/rpm-ostree-%{version}.tar.xz
Patch0: 0001-override-Honor-install-in-container-case-too.patch
Patch1: 0002-scripts-also-ignore-kernel-debug-modules.posttrans.patch
ExclusiveArch: %{rust_arches}
BuildRequires: make
@ -48,7 +51,7 @@ BuildRequires: rust
%endif
# For the autofiles bits below
BuildRequires: /usr/bin/python3
BuildRequires: python3-devel
# We always run autogen.sh
BuildRequires: autoconf automake libtool git
# For docs
@ -190,8 +193,8 @@ for line in sys.argv[1:]:
else:
sys.stderr.write('{0} did not match any files\n'.format(line))
EOF
PYTHON=python3
if ! test -x /usr/bin/python3; then
PYTHON='%{python3}'
if ! test -x '%{python3}'; then
PYTHON=python2
fi
$PYTHON autofiles.py > files \
@ -227,8 +230,19 @@ $PYTHON autofiles.py > files.devel \
%files devel -f files.devel
%changelog
* Mon Mar 13 2023 Colin Walters <walters@verbum.org> - 2022.10.115.g15eba7b1-2
- Resolves: rhbz#2177225
* Thu Oct 05 2023 Joseph Marrero <jmarrero@fedoraproject.org> - 2022.10.117.g52714b51-3
- Use python macros and devel package
Resolves: #RHEL-2243
* Mon Aug 07 2023 Joseph Marrero <jmarrero@fedoraproject.org> - 2022.10.117.g52714b51-2
- Backport fb97c48f3 & eae7e1d8
https://github.com/coreos/rpm-ostree/commit/fb97c48f3cd070c1ad559f3f43f86ad6548f6b02
https://github.com/coreos/rpm-ostree/commit/eae7e1d8d692b5ce6d3d6eef29abbd7512ae4682
Resolves: rhbz#2229804
* Sun Apr 30 2023 Joseph Marrero <jmarrero@fedoraproject.org> - 2022.10.117.g52714b51-1
- Sync to latest rhel8 branch
Resolves: rhbz#2192235
* Thu Feb 16 2023 Colin Walters <walters@verbum.org> - 2022.10.112.g3d0ac35b-3
- Cherry pick